@@ -7,7 +7,7 @@ package Excel::Writer::XLSX::Workbook;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2020, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2021, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -34,7 +34,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Utility qw(xl_cell_to_rowcol xl_rowcol_to_cell);
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 
 ###############################################################################
@@ -99,6 +99,7 @@ sub new {
     $self->{_excel2003_style}    = 0;
     $self->{_max_url_length}     = 2079;
     $self->{_has_comments}       = 0;
+    $self->{_read_only}          = 0;
 
     $self->{_default_format_properties} = {};
 
@@ -214,6 +215,9 @@ sub _assemble_xml_file {
     # Write the XLSX file version.
     $self->_write_file_version();
 
+    # Write the fileSharing element.
+    $self->_write_file_sharing();
+
     # Write the workbook properties.
     $self->_write_workbook_pr();
 
@@ -1043,6 +1047,20 @@ sub set_vba_name {
 }
 
 
+###############################################################################
+#
+# read_only_recommended()
+#
+# Set the Excel "Read-only recommended" save option.
+#
+sub read_only_recommended {
+
+    my $self = shift;
+
+    $self->{_read_only} = 2;
+}
+
+
 ###############################################################################
 #
 # set_calc_mode()
@@ -1069,6 +1087,7 @@ sub set_calc_mode {
 }
 
 
+
 ###############################################################################
 #
 # get_default_url_format()
@@ -2545,6 +2564,24 @@ sub _write_file_version {
 }
 
 
+##############################################################################
+#
+# _write_file_sharing()
+#
+# Write the <fileSharing> element.
+#
+sub _write_file_sharing {
+
+    my $self = shift;
+
+    return if !$self->{_read_only};
+
+    my @attributes = ( 'readOnlyRecommended' => 1, );
+
+    $self->xml_empty_tag( 'fileSharing', @attributes );
+}
+
+
 ###############################################################################
 #
 # _write_workbook_pr()
@@ -2826,6 +2863,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-(c) MM-MMXX, John McNamara.
+(c) MM-MMXXI, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
